Misc
--------------

*check_type()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.check_type

*expspace()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.expspace

*find_closest()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.find_closest

*find_consecutive()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.find_consecutive

*find_groups()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.find_groups

*find_outliers()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.find_outliers

*find_plateau()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.find_plateau

*find_knee()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.find_knee

*listify()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.listify

*parallel_run()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.parallel_run

*progress_bar()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.progress_bar

*replace()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.replace

*as_vector()*
""""""""""""""""""""""""""
.. autofunction:: neurokit2.misc.as_vector


*Any function appearing below this point is not explicitly part of the documentation and should be added. Please open an issue if there is one.*

.. automodule:: neurokit2.misc
   :members:
   :exclude-members: check_type, expspace, find_closest, find_consecutive, find_groups, find_outliers, find_plateau, intervals_to_peaks, listify, parallel_run, progress_bar, replace, as_vector, find_knee

